@@ -2,13 +2,13 @@
 #'
 #' @description Extracts coefficients from a DMR object.
 #'
-#' @param object Fitted DMR object.
+#' @param object Fitted \code{DMR} object.
 #'
 #' @param df Number of parameters in the model for which coefficients are required. Default is the entire path of models.
 #'
 #' @param ... Further arguments passed to or from other methods.
 #'
-#' @details Similar to other coef methods, this function extracts coefficients from a fitted DMR object.
+#' @details Similar to other \code{coef} methods, this function extracts coefficients from a fitted \code{DMR} object.
 #'
 #' @return Vector or matrix of coefficients.
 #'
@@ -25,9 +25,9 @@ coef.DMR <- function(object, df = NULL, ...){
                          colnames(out) <- paste("df", object$df, sep = "")
                          return(out)
          }
-         if(class(df) != "numeric" & class(df) != "integer"){
+         if(!inherits(df, "numeric") & !inherits(df, "integer")){
                       stop("Error: wrong input type, df should have type numeric")
          }
          out <- object$beta[,ncol(object$beta) - df + 1]
-         return(out)
+         return(out[out!=0.0])
 }
